@@ -62,7 +62,7 @@ our %isKnownAttribute = (
     font        => _hash( @core, @i18n, qw( color face size ) ),
     form        => _hash( @std, qw( accept-charset action enctype method name onreset onsubmit target ) ),
     frame       => _hash( @core, qw( frameborder longdesc marginheight marginwidth name noresize scrolling src ) ),
-    frameset    => _hash( @core, qw( cols onload onunload rows ) ),
+    frameset    => _hash( @core, qw( cols onload onunload rows border bordercolor frameborder framespacing ) ),
     h1          => _hash( @std, qw( align ) ),
     h2          => _hash( @std, qw( align ) ),
     h3          => _hash( @std, qw( align ) ),
@@ -81,7 +81,6 @@ our %isKnownAttribute = (
     legend      => _hash( @std, qw( accesskey align ) ),
     li          => _hash( @std, qw( type value ) ),
     'link'      => _hash( @std, qw( charset href hreflang media rel rev target type ) ),
-    listing     => _hash(),
     'map'       => _hash( @std, qw( name ) ),
     menu        => _hash( @std, qw( compact ) ),
     meta        => _hash( @i18n, qw( content http-equiv name scheme ) ),
@@ -100,7 +99,6 @@ our %isKnownAttribute = (
     script      => _hash( qw( charset defer event for language src type ) ),
     'select'    => _hash( @std, qw( disabled multiple name onblur onchange onfocus size tabindex ) ),
     span        => _hash( @std ),
-    strong      => _hash(),
     style       => _hash( @i18n, qw( media title type ) ),
     table       => _hash( @std,
                     qw( align bgcolor border cellpadding cellspacing datapagesize frame rules summary width ),
